export declare const version = "v1.3.3";
export interface Config {
    varsnap: string | boolean;
    env: string;
    producerToken?: string;
    consumerToken?: string;
    logger?: Logger;
}
declare type ConfigKeys = keyof Config;
export interface Logger {
    debug(s: string): void;
    log(s: string): void;
    error(s: string): void;
}
export declare class Util {
    static logger: Logger;
    static getConfig(config: Config, configKey: ConfigKeys): string;
    static getSignature(targetFunc: TargetFunction): string;
    static ajax(url: string, requestData: object): Promise<object>;
    static debug(data: string): void;
    static log(data: string): void;
    static error(data: string): void;
    static resetProducers(): void;
    static resetConsumers(): void;
    static getProducers(): Producer[];
    static getConsumers(): Consumer[];
    static limitString(x: TargetFunctionInput[] | TargetFunctionOutput): string;
}
export declare class Producer {
    targetFunc: TargetFunction;
    config: Config;
    constructor(targetFunc: TargetFunction, config: Config);
    isEnabled(): boolean;
    static serialize(data: TargetFunctionInput[] | TargetFunctionOutput): string;
    produce(args: TargetFunctionInput[], output: TargetFunctionOutput): void;
}
interface Snap {
    id: string;
    inputs: string;
    prod_outputs: string;
}
export declare class Consumer {
    targetFunc: TargetFunction;
    config: Config;
    constructor(targetFunc: TargetFunction, config: Config);
    isEnabled(): boolean;
    static deserialize(data: string): TargetFunctionInput[] | TargetFunctionOutput | undefined;
    consumeOnce(): Promise<boolean>;
    reportCentral(snap: Snap, localOutputs: TargetFunctionOutput, matches: boolean): Promise<string | boolean>;
    reportLog(snapID: string, inputs: TargetFunctionInput[], prodOutputs: TargetFunctionOutput, localOutputs: TargetFunctionOutput, matches: boolean, trialURL: string | boolean): void;
}
export declare type TargetFunctionInput = any;
export declare type TargetFunctionOutput = any;
export interface TargetFunction {
    (...args: TargetFunctionInput[]): TargetFunctionOutput;
}
export interface WrappedFunction {
    (...args: TargetFunctionInput[]): TargetFunctionOutput;
    producer: Producer;
    consumer: Consumer;
}
export declare function varsnap(func: TargetFunction): TargetFunction | WrappedFunction;
export declare namespace varsnap {
    var config: Config;
    var version: string;
    var runTests: typeof import("./core").runTests;
}
export declare function runTests(): Promise<boolean>;
export {};
